prainsa package
===============

Subpackages
-----------

.. toctree::

    prainsa.loader
    prainsa.plotly_plot

Submodules
----------

prainsa\.channel module
-----------------------

.. automodule:: prainsa.channel
    :members:
    :undoc-members:
    :show-inheritance:

prainsa\.epoch module
---------------------

.. automodule:: prainsa.epoch
    :members:
    :undoc-members:
    :show-inheritance:

prainsa\.prainsa module
-----------------------

.. automodule:: prainsa.prainsa
    :members:
    :undoc-members:
    :show-inheritance:

prainsa\.speed\_up module
-------------------------

.. automodule:: prainsa.speed_up
    :members:
    :undoc-members:
    :show-inheritance:

prainsa\.utilities module
-------------------------

.. automodule:: prainsa.utilities
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: prainsa
    :members:
    :undoc-members:
    :show-inheritance:
